@@ -139,7 +139,7 @@ metar_decode <- function(x, metric = TRUE, altimeter = FALSE,
                       Dew_point = metar_dew_point(outx$Original_METAR),
                       Pressure = metar_pressure(outx$Original_METAR, altimeter = altimeter),
                       Pressure_unit = ifelse(!altimeter, "hPa", "mmHg"),
-                      Visibility = metar_visibility(outx$Original_METAR, metric = metric),
+                      Visibility = metar_visibility(outx$Original_METAR, metric = metric, numeric_only = numeric_only),
                       Visibility_unit = ifelse(metric, "m", "mile"),
                       Cloud_coverage = metar_cloud_coverage(outx$Original_METAR, sep = sep),
                       Weather_information = metar_wx_codes(outx$Original_METAR, sep = sep),
