@@ -29,6 +29,10 @@ metar_gust <- function(x, metric = TRUE) {
   }
   out <- c(1:length(x))
   out[1:length(x)] <- NA
+  # Remove part after RMK
+  x <- stringr::str_split_fixed(x, pattern = "RMK", n = 2)[,1]
+  # Remove part after TEMPO
+  x <- stringr::str_split_fixed(x, pattern = "TEMPO", n = 2)[,1]
   fKT <- stringr::str_detect(x, pattern = "G\\d\\dKT")
   out[fKT] <- as.numeric(stringr::str_sub(stringr::str_extract(x[fKT], pattern = "G\\d+KT"), 2, 3)) * cfi
   fMPS <- stringr::str_detect(x, pattern = "G\\d\\dMPS")
